@@ -3,7 +3,7 @@ package Bundle::Dependencies::Catalyst;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 1;
 
@@ -451,7 +451,7 @@ Net::Amazon
 
 Log::Log4perl
 
-I18N::LangTags::Detect
+I18N::LangTags
 
 ExtUtils::Manifest
 
@@ -573,8 +573,6 @@ Test::Builder
 
 Test::Builder::Tester
 
-Wx
-
 Alien
 
 Alien::wxWidgets
